# edited https://github.com/KitWallace/pipico example code by MJ 16052021
# Connect Pico pin-0 --- SDA, pin-1 ---- SCL
#

from machine import Pin, I2C, Timer
from BMX280 import BMX280
from Carray import Circular_Array
import time
import ssd1306

# OLED display
WIDTH  = 128                                            # oled display width
HEIGHT = 64                                             # oled display height

# barometer
BARO_ADDR= 118
ELEVATION = 527  # Bhopal in metres above Sea Level
ALPHA = 0.8  # smoothing constant

global pressure
pressure = None


# setup BMP280 in I2C mode
sda=machine.Pin(0)
scl=machine.Pin(1)
i2c=machine.I2C(0,sda=sda, scl=scl, freq=400000)

# setup OLED display in SPI mode
spi_sck=machine.Pin(2)
spi_tx=machine.Pin(3)
spi=machine.SPI(0,baudrate=100000,sck=spi_sck, mosi=spi_tx)
CS = machine.Pin(1)
DC = machine.Pin(4)
RES = machine.Pin(5)
oled = ssd1306.SSD1306_SPI(128, 64, spi, DC, RES, CS)

#show intro message
oled.fill(0)
oled.text('Raspberry', 0, 0, 1)
oled.text('Pi Pico Project', 0, 10, 1)
oled.text('using SSD1306 &', 0, 20, 1)
oled.text('BMP280', 0, 30, 1)
oled.show()
time.sleep(2)

baro = BMX280(i2c,BARO_ADDR)

#print(baro.chip_id)
#baro.print_calibration()

def adjust_for_elevation(pressure,elevation):
    return pressure +elevation/9.2

while True:
    global pressure
    global pressure_old
    pressure_read = baro.pressure/100
    temp = baro.temperature
    sl_pressure = round(adjust_for_elevation(pressure_read,ELEVATION),1)
    pressure = sl_pressure
    
    print ("Pressure: "+"%.2f mBar" % pressure)
    print ("temp: "+"%.2f °C" % temp)
    print ("=======================================")
    
    oled.fill(0)
    oled.text("Pressure: ", 0, 0, 1)
    oled.text("%.2f mBar" % pressure, 20, 10, 1)
    oled.text("Temprature: ", 0, 20, 1)
    oled.text("%.2f *C" % temp, 20, 30, 1)
    oled.show()
    time.sleep (1)

